summaryrefslogtreecommitdiff
path: root/src/mongo/client/remote_command_targeter.h
diff options
context:
space:
mode:
authorGabriel Russell <gabriel.russell@mongodb.com>2020-10-19 12:52:15 -0400
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-11-09 16:58:10 +0000
commitacff91727f94716ca3f1a1e3d8d839d17f07b3d9 (patch)
treea354b59edb3d38103a5e79cbce915fd2b3f7afa7 /src/mongo/client/remote_command_targeter.h
parent8e777baedf13e0ee2cc366ef6a6420e0badcf0d2 (diff)
downloadmongo-acff91727f94716ca3f1a1e3d8d839d17f07b3d9.tar.gz
SERVER-50510 Change markHostNotMaster to markHostNotPrimary
Diffstat (limited to 'src/mongo/client/remote_command_targeter.h')
-rw-r--r--src/mongo/client/remote_command_targeter.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/client/remote_command_targeter.h b/src/mongo/client/remote_command_targeter.h
index 6e9cfcd582f..4c42a499ba0 100644
--- a/src/mongo/client/remote_command_targeter.h
+++ b/src/mongo/client/remote_command_targeter.h
@@ -81,11 +81,11 @@ public:
const ReadPreferenceSetting& readPref, Milliseconds maxWait) = 0;
/**
* Reports to the targeter that a 'status' indicating a not master error was received when
* communicating with 'host', and so it should update its bookkeeping to avoid giving out the
* host again on a subsequent request for the primary.
*/
- virtual void markHostNotMaster(const HostAndPort& host, const Status& status) = 0;
+ virtual void markHostNotPrimary(const HostAndPort& host, const Status& status) = 0;
/**
* Reports to the targeter that a 'status' indicating a network error was received when trying
@@ -81,11 +81,11 @@ public:
const ReadPreferenceSetting& readPref, Milliseconds maxWait) = 0;
/**
- * Reports to the targeter that a 'status' indicating a not master error was received when
+ * Reports to the targeter that a 'status' indicating a not primary error was received when
* communicating with 'host', and so it should update its bookkeeping to avoid giving out the
* host again on a subsequent request for the primary.